@@ -170,7 +170,7 @@ class Hamiltonian():
     @get_docstring(ldos.get_ldos)
     def get_ldos(self,**kwargs):
         return ldos.get_ldos(self,**kwargs)
-    def get_gk_gen(self,delta=0.05,operator=None,canonical_phase=False):
+    def get_gk_gen(self,delta=1e-3,operator=None,canonical_phase=False):
       """Return the Green function generator"""
       hkgen = self.get_hk_gen() # Hamiltonian generator
       def f(k=[0.,0.,0.],e=0.0):
@@ -217,6 +217,9 @@ class Hamiltonian():
     def get_kdos_bands(self,**kwargs):
         from .kdos import kdos_bands
         return kdos_bands(self,**kwargs)
+    def get_surface_kdos(self,**kwargs):
+        from .kdos import surface_kdos
+        return surface_kdos(self,**kwargs)
     def add_sublattice_imbalance(self,mass):
       """ Adds a sublattice imbalance """
       if self.geometry.has_sublattice and self.geometry.sublattice_number==2:
@@ -250,6 +253,7 @@ class Hamiltonian():
         return hamiltonianmode.same_hamiltonian(self,*args,**kwargs)
     def get_supercell(self,nsuper,**kwargs):
       """ Creates a supercell of a one dimensional system"""
+      if nsuper is None: return self # do nothing
       if nsuper==1: return self
       if self.dimensionality==0: return self
       try: 
@@ -552,12 +556,11 @@ class Hamiltonian():
     def write_magnetization(self,**kwargs):
         from .htk.write import write_magnetization
         write_magnetization(self,**kwargs)
-    def write_onsite(self,nrep=5,normal_order=False):
+    def write_onsite(self,zero_average=False,**kwargs):
         """Extract onsite energy"""
         d = self.extract("density")
-        d = d - np.mean(d)
-        self.geometry.write_profile(d,name="ONSITE.OUT",
-                normal_order=normal_order,nrep=nrep)
+        if zero_average: d = d - np.mean(d)
+        self.geometry.write_profile(d,name="ONSITE.OUT",**kwargs)
     def write_hopping(self,**kwargs):
         groundstate.hopping(self,**kwargs)
     def write_anomalous_hopping(self,**kwargs):
